@@ -24,7 +24,7 @@ import aiohttp.abc
 import yaml
 from aiohttp_socks import ProxyConnector
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 __author__ = "s3rgeym"
 
 # При запуске отладчика VS Code устанавливает переменную PYDEVD_USE_FRAME_EVAL=NO
@@ -341,6 +341,7 @@ class Scanner:
     # TODO: переименовать
     async def produce(self, urls: typing.Iterable[str]) -> None:
         for url in urls:
+            # .hostname переводится в нижний регистр
             if self.is_ignored_host(urllib.parse.urlsplit(url).hostname):
                 log.debug(f"skip ignored host url: {url}")
                 continue
@@ -372,10 +373,10 @@ class Scanner:
                 break
 
             try:
-                netloc = urllib.parse.urlsplit(url)
+                netloc = urllib.parse.urlsplit(url).netloc
 
                 if self.error_counter[netloc] >= self.max_host_error:
-                    log.warning(f"max host error: {url}")
+                    log.warning(f"max host error: {netloc}")
                     continue
 
                 headers = conf.get("headers", {}).copy()
@@ -877,7 +878,7 @@ def create_parser() -> argparse.ArgumentParser:
         "--workers",
         help="number of workers",
         type=int,
-        default=20,
+        default=30,
     )
     parser.add_argument(
         "-t",
@@ -940,7 +941,7 @@ def main(argv: typing.Sequence[str] | None = None) -> None | int:
     # True
     if not all(set(item) > ProbeConfig.__required_keys__ for item in probes):
         log.error(
-            f"invalid config: each probes element must have keys: {', '.join(ProbeConfig.__required_keys__)}"
+            f"invalid config: probe required keys: {', '.join(ProbeConfig.__required_keys__)}"
         )
         return 1
 
@@ -955,7 +956,7 @@ def main(argv: typing.Sequence[str] | None = None) -> None | int:
 
     # in set значительно быстрее
     ignore_hosts: set[str] = set(
-        filter(None, map(str.strip, args.ignore_hosts))
+        map(str.lower, filter(None, map(str.strip, args.ignore_hosts)))
         if args.ignore_hosts
         else []
     )
